# Architecture Decision Records

This directory holds Architecture Decision Records (ADRs) for Cognithor,
following the [Nygard template](https://cognitect.com/blog/2011/11/15/documenting-architecture-decisions).

## Records

| #    | Status   | Title                                     | Date       |
|------|----------|-------------------------------------------|------------|
| 0001 | Accepted | [PGE Trinity vs Group Chat](./0001-pge-trinity-vs-group-chat.md) | 2026-04-25 |

## Template

```markdown
# ADR NNNN: <Title>

## Status
Proposed | Accepted | Deprecated | Superseded by ADR-XXXX

## Context
<Forces at play, problem statement, constraints>

## Decision
<The change we're making>

## Consequences

### Positive
- <Benefit 1>
- <Benefit 2>

### Negative / Trade-offs
- <Cost 1>
- <Cost 2>
- <Cost 3>  # at least 3 honest trade-offs

## Alternatives Considered
1. <Option A> — rejected because <reason>
2. <Option B> — rejected because <reason>

## References
- <Source 1>
- <Source 2>
```
